@@ -1,10 +1,14 @@
 import json
 import objectpath
+import pathlib
 
+HERE = (pathlib.Path(__file__).parent)
 # files
-GAME_LEAGUE_ID_FILE = 'files/game_league_ids.json'
-CLEANED_NAMES_FILE = 'files/cleaned_names.json'
-OUTPUT_FILE = 'output/outfile{}.json'
+GAME_LEAGUE_ID_FILE = (HERE / 'files/json/game_league_ids.json')
+CLEANED_NAMES_FILE = (HERE / 'files/json/cleaned_names.json')
+OUTPUT_FILE = (HERE / 'files/output/outfile{}.json')
+
+print(GAME_LEAGUE_ID_FILE)
 
 
 def search_json_key(data, json_key):
